/**
 * @file
 * Dynamic updating of tracking totals.
 */

(function ($, Drupal, drupalSettings) {

  'use strict'

  Drupal.behaviors.commerce_partial_payments_tracking_total = {
    attach: function (context) {
      $.each(drupalSettings.commerce_partial_payments.forms, function (selector, settings) {
        var $form = $(selector, context);
        var $total = $form.find('.cpp-tracking-total');
        var $items = $form.find('.cpp-tracking-amounts .form-type-commerce-number :input');
        var $warning = $form.find('.cpp-tracking-warning');

        $items.change(function(e) {
          // Consistently format the number.
          this.value = parseFloat(this.value).toLocaleString(settings.locale, {
            style: 'currency',
            currency: settings.currency,
            currencyDisplay: 'code'
          }).substr(4);

          // Get the total that has been tracked.
          var total = 0;
          $items.each(function (index) {
            total += parseFloat(this.value || 0);
          });

          // Update the total.
          $total.html(total.toLocaleString(settings.locale, {
            style: 'currency',
            currency: settings.currency
          }));

          // If a warning is configured, show it.
          if (typeof settings.warning !== 'undefined') {
            var warn;

            // Format our warning and total for strict comparisons.
            var warning_amount = parseFloat(settings.warning).toFixed(6);
            total = total.toFixed(6);

            // 'exact' means it must be an exact match.
            if (settings.warning_type === 'exact') {
              warn = total !== warning_amount;
            }
            // Otherwise we assume an upper limit.
            else {
              // As we are comparing formatted fixed precision numbers, a longer
              // string is a bigger number, but the first digit may be lower, so
              // explicitly check both length and a natural comparison.
              // E.g. "10.000000" is greater than "5.000000".
              if (total.length === warning_amount.length) {
                warn = total > warning_amount;
              }
              else {
                warn = total.length > warning_amount.length;
              }
            }

            // Show or hide the warning as required.
            if (warn) {
              $warning.removeClass('hidden');
            }
            else {
              $warning.addClass('hidden');
            }
          }
        });
      });
    }
  }

})(jQuery, Drupal, drupalSettings);
